@@ -1,10 +1,9 @@
 ##  RUnit : A unit test framework for the R programming language
-##  Copyright (C) 2003, 2004  Thomas Koenig, Matthias Burger, Klaus Juenemann
+##  Copyright (C) 2003-2009  Thomas Koenig, Matthias Burger, Klaus Juenemann
 ##
 ##  This program is free software; you can redistribute it and/or modify
 ##  it under the terms of the GNU General Public License as published by
-##  the Free Software Foundation; either version 2 of the License, or
-##  (at your option) any later version.
+##  the Free Software Foundation; version 2 of the License.
 ##
 ##  This program is distributed in the hope that it will be useful,
 ##  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,7 +14,7 @@
 ##  along with this program; if not, write to the Free Software
 ##  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-##  $Id: html.r,v 1.7 2007/11/27 18:52:00 burgerm Exp $
+##  $Id: html.r,v 1.9 2009/04/16 09:45:19 burgerm Exp $
 
 
 writeRaw <- function(htmlStr,htmlFile,append=TRUE)
@@ -49,7 +48,7 @@ writeRawCR <- function(htmlStr,htmlFile,append=TRUE)
   ##
   ##@codestatus : internal 
 
-  writeRaw(htmlStr,htmlFile,append);
+  writeRaw(htmlStr,htmlFile,append)
   cat("\n",file=htmlFile,append=TRUE)
   invisible(TRUE)
 }
@@ -68,9 +67,9 @@ writeTitle <- function(htmlStr,htmlFile,append=TRUE)
   ##
   ##@codestatus : internal
    
-  writeRaw("<title>",htmlFile,append);
-  writeRaw(htmlStr,htmlFile);
-  writeRaw("</title>\n",htmlFile);
+  writeRaw("<title>",htmlFile,append)
+  writeRaw(htmlStr,htmlFile)
+  writeRaw("</title>\n",htmlFile)
 }
 
 
@@ -86,7 +85,7 @@ writeBeginHead <- function(htmlFile,append=TRUE)
   ##
   ##@codestatus : internal
     
-  writeRaw("<head>",htmlFile,append);
+  writeRaw("<head>",htmlFile,append)
 }
 
 
@@ -102,7 +101,7 @@ writeEndHead <- function(htmlFile,append=TRUE)
   ##
   ##@codestatus : internal
     
-  writeRaw("</head>\n",htmlFile,append);
+  writeRaw("</head>\n",htmlFile,append)
 }
 
 
@@ -118,7 +117,7 @@ writeBeginHtml <- function(htmlFile,append=TRUE)
   ##
   ##@codestatus : internal
     
-  writeRaw("<html>",htmlFile,append);
+  writeRaw("<html>",htmlFile,append)
 }
 
 
@@ -134,7 +133,7 @@ writeEndHtml <- function(htmlFile,append=TRUE)
   ##
   ##@codestatus : internal
     
-  writeRaw("</html>\n",htmlFile,append);
+  writeRaw("</html>\n",htmlFile,append)
 }
 
 
@@ -150,7 +149,7 @@ writeBeginBody <- function(htmlFile,append=TRUE)
   ##
   ##@codestatus : internal
     
-  writeRaw("<body>",htmlFile,append);
+  writeRaw("<body>",htmlFile,append)
 }
 
 
@@ -166,7 +165,7 @@ writeEndBody <- function(htmlFile,append=TRUE)
   ##
   ##@codestatus : internal
     
-  writeRaw("</body>\n",htmlFile,append);
+  writeRaw("</body>\n",htmlFile,append)
 }
 
 
@@ -184,13 +183,10 @@ writeBeginTag <- function(htmlTag,htmlFile,para="",append=TRUE)
   ##
   ##@codestatus : internal
    
-  if(para =="")
-  {
-    writeRaw(paste("<",htmlTag,">",sep=""),htmlFile,append);
-  }
-  else
-  {
-    writeRaw(paste("<",htmlTag," ",para,">",sep=""),htmlFile,append);
+  if(para =="") {
+    writeRaw(paste("<",htmlTag,">",sep=""),htmlFile,append)
+  } else {
+    writeRaw(paste("<",htmlTag," ",para,">",sep=""),htmlFile,append)
   }
 
 }
@@ -209,7 +205,7 @@ writeEndTag <- function(htmlTag,htmlFile,append=TRUE)
   ##
   ##@codestatus : internal
     
-  writeRaw(paste("</",htmlTag,">",sep=""),htmlFile,append);
+  writeRaw(paste("</",htmlTag,">",sep=""),htmlFile,append)
 }
 
 
@@ -293,28 +289,26 @@ writeTableRow <- function(row,htmlFile,append=TRUE,bgcolor="")
   ##
   ##@codestatus : internal
     
-  writeBeginTag("tr",htmlFile);
+  writeBeginTag("tr",htmlFile)
   if(length(bgcolor) == 1)
   {
-    bgcolor <- rep(bgcolor,length(row));
+    bgcolor <- rep(bgcolor,length(row))
   }
   for(i in seq_along(row))
   {
     if(bgcolor[i] == "")
     {
-      writeBeginTag("td",htmlFile);
+      writeBeginTag("td",htmlFile)
+    } else {
+      writeBeginTag("td",htmlFile,para=paste("bgcolor=\"",bgcolor[i],"\"",sep=""))
     }
-    else
-    {
-      writeBeginTag("td",htmlFile,para=paste("bgcolor=\"",bgcolor[i],"\"",sep=""));
-    }
-    writeRaw(row[i],htmlFile);
-    writeEndTag("td",htmlFile);
-    writeCR(htmlFile);
+    writeRaw(row[i],htmlFile)
+    writeEndTag("td",htmlFile)
+    writeCR(htmlFile)
   }
 
-  writeEndTag("tr",htmlFile,append);
-  writeCR(htmlFile);
+  writeEndTag("tr",htmlFile,append)
+  writeCR(htmlFile)
 }
 
 
@@ -332,9 +326,9 @@ writeLink <- function(target,name,htmlFile,append=TRUE)
   ##
   ##@codestatus : internal
     
-  writeBeginTag("a",htmlFile,paste("href=\"",target,"\"",sep=""),append=append);
-  writeRaw(name,htmlFile,append=TRUE);
-  writeEndTag("a",htmlFile,append=TRUE);
+  writeBeginTag("a",htmlFile,paste("href=\"",target,"\"",sep=""),append=append)
+  writeRaw(name,htmlFile,append=TRUE)
+  writeEndTag("a",htmlFile,append=TRUE)
 }
 
 
@@ -350,8 +344,8 @@ writeEndTable <- function(htmlFile,append=TRUE)
   ##
   ##@codestatus : internal
   
-  writeEndTag("table",htmlFile,append);
-  writeCR(htmlFile);
+  writeEndTag("table",htmlFile,append)
+  writeCR(htmlFile)
 }
 
 
@@ -373,13 +367,14 @@ writeHtmlHeader <- function(header,htmlFile)
   ##
   ##@codestatus : internal
   
-  writeRawCR("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",htmlFile,FALSE);
-  writeRawCR("\"http://www.w3.org/TR/html4/transitional.dtd\">",htmlFile);
-  writeBeginHtml(htmlFile);
-  writeBeginHead(htmlFile);
-  writeTitle(header,htmlFile);
-  writeEndHead(htmlFile);
-  writeBeginBody(htmlFile);
+  writeRawCR("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",
+             htmlFile,FALSE)
+  writeRawCR("\"http://www.w3.org/TR/html4/transitional.dtd\">",htmlFile)
+  writeBeginHtml(htmlFile)
+  writeBeginHead(htmlFile)
+  writeTitle(header,htmlFile)
+  writeEndHead(htmlFile)
+  writeBeginBody(htmlFile)
 }
 
 
@@ -394,8 +389,8 @@ writeHtmlEnd <- function(htmlFile)
   ##
   ##@codestatus : internal
   
-  writeEndBody(htmlFile);
-  writeEndHtml(htmlFile);
+  writeEndBody(htmlFile)
+  writeEndHtml(htmlFile)
 }
 
 
@@ -410,7 +405,7 @@ writeHtmlSep <- function(htmlFile)
   ##
   ##@codestatus : internal
   
-  writeRawCR("<hr>",htmlFile);
+  writeRawCR("<hr>",htmlFile)
 }
 
 
@@ -427,8 +422,8 @@ writeImage <- function(img,htmlFile,append=TRUE)
   ##
   ##@codestatus : internal
   
-  writeBeginTag("img",htmlFile,para=paste("src=\"",img,"\"",sep=""),append);
-  writeEndTag("img",htmlFile);
+  writeBeginTag("img",htmlFile,para=paste("src=\"",img,"\"",sep=""),append)
+  writeEndTag("img",htmlFile)
 }
 
 
@@ -447,10 +442,10 @@ writeHtmlSection <- function(title,sec,htmlFile,append=TRUE)
   ##@codestatus : internal
   
   secTag <- paste("h",sec,sep="")
-  writeBeginTag(secTag,htmlFile,append);
-  writeRaw(title,htmlFile,append);
-  writeEndTag(secTag,htmlFile,append);
-  writeCR(htmlFile,append);
+  writeBeginTag(secTag,htmlFile,append)
+  writeRaw(title,htmlFile,append)
+  writeEndTag(secTag,htmlFile,append)
+  writeCR(htmlFile,append)
 }
 
 
